@@ -1,6 +1,6 @@
 from searcher import SolrSearcher, CommonSearcher
 from query import SolrQuery, SolrError
-from util import X
+from util import X, LocalParams
 
 
-__version__ = (0, 2, 11, 'alpha')
+__version__ = (0, 2, 12, 'alpha')
